@@ -1,6 +1,6 @@
 from django.contrib import admin
-from models import Category, CategoryAdmin
- 
+
+from .models import Category, CategoryAdmin
+
+
 admin.site.register(Category, CategoryAdmin)
-
-
